@@ -448,6 +448,9 @@ public final class Main {
             }
         }
 
+        // Activated the module finder
+        ModuleLoggerFinder.activate(bootClassLoader);
+
         if (! agentJars.isEmpty()) {
             final Instrumentation instrumentation = Main.instrumentation;
             if (instrumentation == null) {
